<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class HomeAgencySlider extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'home-agency-slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home Agency - Slider Widget', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-agency' ];
	}

	public function get_keywords() {
		return [ 'Slider', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_slider',
			[
				'label' => esc_html__( 'Slider Area', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Slider Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'        => 'slider_select',
						'label'     => esc_html__( 'Slider Select', 'bdevs-elementor' ),
						'type'      => Controls_Manager::SELECT,
						'dynamic' => [ 'active' => true ],
						'options'   => [
							'1'  => esc_html__( 'Inactive', 'bdevs-elementor' ),
							'2'  => esc_html__( 'Active', 'bdevs-elementor' ),
						],
						'default'   => '1',
					],	
				    [
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),
					],			
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'tab_content',
						'label'      => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXTAREA,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( '', 'bdevs-elementor' ),
					],
					[
						'name'        => 'tab_link',
						'label'       => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
					],
					[
						'name'        => 'tab_button',
						'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],
				],
			]
		);

		$this->add_control(
			'previous_btn',
			[
				'label'       => __( 'Previous Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Previous Button', 'bdevs-elementor' ),
				'default'     => __( 'It is Previous Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'next_btn',
			[
				'label'       => __( 'Next Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Next Button', 'bdevs-elementor' ),
				'default'     => __( 'It is Next Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		
	    
		$this->end_controls_section();


		
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		); 

		$this->add_control(
		    'show_next_btn',
		    [
		        'label'   => esc_html__( 'Show Next Button', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_previous_btn',
		    [
		        'label'   => esc_html__( 'Show Previous Button', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		?>

		<div class="adco-slider-section-padding">

			<div class="container-fluid">

				<div class="row">

					<div class="col-md-12 col-sm-12">

						<!-- Carousel Slider -->

						<div id="carouselYscottIndicators" class="carousel slide" data-ride="carousel">

							<div class="carousel-inner">

								<?php foreach ( $settings['tabs'] as $item ) : ?>

									<?php if( wp_kses_post($item['slider_select']) == '1'): ?>
										<div class="carousel-item">
									<?php elseif( wp_kses_post($item['slider_select']) == '2'): ?>
										<div class="carousel-item active">
									<?php endif; ?> 

										<div class="yscott-content-home">

											<div class="yscott-view-on-mobile animate-box" data-animate-effect="fadeInRight">

												<?php if ( '' !== $item['tab_title'] ) : ?>
													<h1><?php echo wp_kses_post($item['tab_title']); ?></h1>
												<?php endif; ?>

												<?php if ( '' !== $item['tab_subtitle'] ) : ?>
													<p class="yscott-p-subtitle"><?php echo wp_kses_post($item['tab_subtitle']); ?></p>
												<?php endif; ?>

											</div> 
											<?php if ( '' !== $item['tab_image']['url'] ) : ?>
												<a href="<?php echo wp_kses_post($item['link']); ?>"><img class="img yscott-img-home yscott-img-home-left animate-box" data-animate-effect="fadeInLeft" src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt=""></a>
											<?php endif; ?>

											<div class="yscott-content-text yscott-content-text-right">

												<div class="yscott-content-absolute yscott-content-absolute-right">

													<div class="yscott-not-view-on-mobile animate-box" data-animate-effect="fadeInRight">

														<?php if ( '' !== $item['tab_title'] ) : ?>
															<h1><a href="<?php echo wp_kses_post($item['tab_link']); ?>"><?php echo wp_kses_post($item['tab_title']); ?></a></h1>
														<?php endif; ?>

														<?php if ( '' !== $item['tab_subtitle'] ) : ?>
															<p class="yscott-p-subtitle style-1"><?php echo wp_kses_post($item['tab_subtitle']); ?></p>
														<?php endif; ?>

													</div>

													<?php if ( '' !== $item['tab_content'] ) : ?>
														<p class="text yscott-text-home animate-box" data-animate-effect="fadeInRight"><?php echo wp_kses_post($item['tab_content']); ?></p>
													<?php endif; ?>

												</div>

												<div class="yscott-color-button animate-box" data-animate-effect="fadeInRight">

													<div class="yscott-button-link">

														<?php if ( '' !== $item['tab_button'] ) : ?>
															<a href="<?php echo wp_kses_post($item['tab_link']); ?>">

																<div class="btn-contact style-1"><?php echo wp_kses_post($item['tab_button']); ?></div>

															</a> 
														<?php endif; ?>
														<span class="yscott-button-block yscott-button-block-grey animation-bounce"></span> 
													</div>

												</div>

											</div>

										</div>

									</div>

								<?php endforeach; ?>

								<?php if (( '' !== $settings['previous_btn'] ) && ( $settings['show_previous_btn'] )): ?>
									<a class="carousel-control-prev" href="#carouselYscottIndicators" role="button" data-slide="prev"> <span class="carousel-control-prev-icon" aria-hidden="true"></span> <span class="sr-only"><?php echo wp_kses_post($settings['previous_btn']); ?></span> </a>
								<?php endif; ?>

								<?php if (( '' !== $settings['next_btn'] ) && ( $settings['show_next_btn'] )): ?>
									<a class="carousel-control-next" href="#carouselYscottIndicators" role="button" data-slide="next"> <span class="carousel-control-next-icon" aria-hidden="true"></span> <span class="sr-only"><?php echo wp_kses_post($settings['next_btn']); ?></span> </a>
								<?php endif; ?>

							</div>

						</div>

					</div>

				</div>

			</div>

		</div>

		
	<?php
	}

}
