<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class HomeAgencyWork extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'home-agency-work';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Home Agency - Work Widget', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Slider widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Slider widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'home-agency' ];

	}



	public function get_keywords() {

		return [ 'Work', 'carousel' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_work',

			[

				'label' => esc_html__( 'Work Area', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'work_select',

			[

				'label'     => esc_html__( 'Work Select', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'dynamic' => [ 'active' => true ],

				'options'   => [

					'1'  => esc_html__( 'In Home Personal', 'bdevs-elementor' ),

					'2'  => esc_html__( 'In Work Page', 'bdevs-elementor' ),

				],

				'default'   => '1',

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),

				'default'     => __( 'It is Heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'sub_heading',

			[

				'label'       => __( 'Heading Meta', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your heading meta', 'bdevs-elementor' ),

				'default'     => __( 'It is Heading Meta', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);	



		$this->add_control(

			'post_number',

			[

				'label'       => __( 'Post Number', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXT,

				'placeholder' => __( 'Post Number', 'bdevs-elementor' ),

				'default'     => __( '2', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'post_order',

			[

				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'options'   => [

					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),

					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),

				],

				'default'   => 'asc',

			]

		);	

	    

		$this->end_controls_section();





		

		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'center',

			]

		); 



		$this->add_control(

		    'show_heading',

		    [

		        'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

		        'type'    => Controls_Manager::SWITCHER,

		        'default' => 'yes',

		    ]

		);



		$this->add_control(

		    'show_sub_heading',

		    [

		        'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),

		        'type'    => Controls_Manager::SWITCHER,

		        'default' => 'yes',

		    ]

		);



		$this->end_controls_section();



	}



	public function render() {



		$settings  = $this->get_settings_for_display();

		?>



		<?php if( wp_kses_post($settings['work_select']) == '1'): ?>

		<div id="work" class="adco-section-padding">

		<?php elseif( wp_kses_post($settings['work_select']) == '2'): ?>

		<div class="adco-section-padding mb-60">

		<?php endif; ?> 



			<div class="container-fluid">



				<div class="row">



					<div class="col-md-12"> 

						<?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>

						<span class="heading-meta style-1"><?php echo wp_kses_post($settings['sub_heading']); ?></span>

					<?php endif; ?>



					<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>

					<h2 class="adco-heading animate-box" data-animate-effect="fadeInUp"><?php echo wp_kses_post($settings['heading']); ?></h2>

				<?php endif; ?>



			</div>



		</div>



		<div class="row">



			<?php $i = 0;

			$order = $settings['post_order'];

			$post_number = $settings['post_number'];

			$wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'work',  'orderby' => 'ID', 'order' => $order));



			while ($wp_query -> have_posts()) : $wp_query -> the_post(); 

				$cates = get_the_terms(get_the_ID(),'type');

				$cate_name ='';

				$cate_slug ='';

				foreach((array)$cates as $cate){

					if(count($cates)>0){

						$cate_name .= $cate->name.'<p class="cate-name">, </p>';

						$cate_slug .= $cate->slug.' ';   

					} 

				} 

				$i++;

				?>



				<div class="col-md-6 animate-box" data-animate-effect="fadeInUp">



					<a href="<?php the_permalink();?>" class="desc">



						<div class="project"> <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" class="img-fluid" alt="">



							<div class="desc">



								<div class="con centered">



									<h3><?php the_title();?></h3>



									<div class="work-type"><?php echo $cate_name ?></div> 



								</div>



							</div>



						</div>



					</a>



				</div>



			<?php endwhile; ?>



		</div>



	</div>



</div>



		

	<?php

	}



}

