<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class HomePersonalAbout extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'home-personal-about';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home Personal - About Widget', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-personal' ];
	}

	public function get_keywords() {
		return [ 'About', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_about',
			[
				'label' => esc_html__( 'About Area', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'heading_meta',
			[
				'label'       => __( 'Heading Meta', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Heading Meta', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading Meta', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'team_name',
			[
				'label'       => __( 'Team Name', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Team Name', 'bdevs-elementor' ),
				'default'     => __( 'It is Team Name', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'team_position',
			[
				'label'       => __( 'Team Position', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Team Position', 'bdevs-elementor' ),
				'default'     => __( 'It is Team Position', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'title_meta',
			[
				'label'       => __( 'Title Meta', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Title Meta', 'bdevs-elementor' ),
				'default'     => __( 'It is Title Meta', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Title', 'bdevs-elementor' ),
				'default'     => __( 'It is Title', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Content', 'bdevs-elementor' ),
				'default'     => __( 'It is Content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Tab Skill', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [	
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Tab Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_percent',
						'label'       => esc_html__( 'Tab Percent', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_icon',
						'label'       => esc_html__( 'Tab Icon', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();


		
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		); 

		$this->add_control(
		    'show_heading_meta',
		    [
		        'label'   => esc_html__( 'Show Heading Meta', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_heading',
		    [
		        'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_image',
		    [
		        'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_team_name',
		    [
		        'label'   => esc_html__( 'Show Team Name', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_team_position',
		    [
		        'label'   => esc_html__( 'Show Team Position', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_title_meta',
		    [
		        'label'   => esc_html__( 'Show Title Meta', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_title',
		    [
		        'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_content',
		    [
		        'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		?>

		<div id="about" class="adco-section-padding adco-section-padding-2">

			<div class="container-fluid">

				<div class="row">

					<div class="col-md-12"> 

						<?php if (( '' !== $settings['heading_meta'] ) && ( $settings['show_heading_meta'] )): ?>
						<span class="heading-meta style-1"><?php echo wp_kses_post($settings['heading_meta']); ?></span>
						<?php endif; ?>

						<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
						<h2 class="adco-heading animate-box" data-animate-effect="fadeInUp"><?php echo wp_kses_post($settings['heading']); ?></h2>
						<?php endif; ?>

					</div>

				</div>

				<div class="row">

					<div class="col-md-6">

						<div class="team-holder animate-box" data-animate-effect="fadeInUp">

							<div class="team-image-holder"> 

								<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
								<img src="<?php echo wp_kses_post($settings['image']['url']); ?>" class="img-fluid" alt="">
								<?php endif; ?>

								<div class="team-side-info">

									<?php if (( '' !== $settings['team_name'] ) && ( $settings['show_team_name'] )): ?>
									<h4 class="team-name"><?php echo wp_kses_post($settings['team_name']); ?></h4>
									<?php endif; ?>

									<?php if (( '' !== $settings['team_position'] ) && ( $settings['show_team_position'] )): ?>
									<h6 class="team-position"><?php echo wp_kses_post($settings['team_position']); ?></h6>
									<?php endif; ?>

								</div>

							</div>

						</div>

					</div>

					<div class="col-md-6 animate-box" data-animate-effect="fadeInUp"> 

						<?php if (( '' !== $settings['title_meta'] ) && ( $settings['show_title_meta'] )): ?>
						<span class="heading-meta style-1"><?php echo wp_kses_post($settings['title_meta']); ?></span>
						<?php endif; ?>

						<?php if (( '' !== $settings['title'] ) && ( $settings['show_title'] )): ?>
						<h3 class="adco-about-heading"><?php echo wp_kses_post($settings['title']); ?></h3>
						<?php endif; ?>

						<?php if (( '' !== $settings['content'] ) && ( $settings['show_content'] )): ?>
						<?php echo wp_kses_post($settings['content']); ?>
						<?php endif; ?>

						<br>

						<?php foreach ( $settings['tabs'] as $item ) : ?>

						<?php if ( '' !== $item['tab_title'] ) : ?>
						<p class="bar-title"><?php echo wp_kses_post($item['tab_title']); ?><span class="percent align-right"><?php echo wp_kses_post($item['tab_percent']); ?></span></p>
						<?php endif; ?>

						<?php if ( '' !== $item['tab_icon'] ) : ?>
						<div class="bar">

							<div class="bar-fill <?php echo wp_kses_post($item['tab_icon']); ?> start"></div>

						</div>
						<?php endif; ?>

						<?php endforeach; ?>

					</div>

				</div>

			</div>

		</div>


		
	<?php
	}

}
