<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class HomePersonalProcess extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'home-personal-process';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home Personal - Process Widget', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-personal' ];
	}

	public function get_keywords() {
		return [ 'Process', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_process',
			[
				'label' => esc_html__( 'Process Area', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Process Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Process Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'heading_meta',
			[
				'label'       => __( 'Heading Meta', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Heading Meta', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading Meta', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Tab Process', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [	
					[
						'name'        => 'process_select',
						'label'     => esc_html__( 'Process Select', 'bdevs-elementor' ),
						'type'      => Controls_Manager::SELECT,
						'dynamic' => [ 'active' => true ],
						'options'   => [
							'1'  => esc_html__( 'Top', 'bdevs-elementor' ),
							'2'  => esc_html__( 'Bottom', 'bdevs-elementor' ),
						],
						'default'   => '1',
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),
					],
					[
						'name'        => 'tab_number',
						'label'       => esc_html__( 'Tab Number', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Tab Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Tab Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_icon',
						'label'       => esc_html__( 'Tab Icon', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();


		
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
		    'show_image',
		    [
		        'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		); 

		$this->add_control(
		    'show_heading_meta',
		    [
		        'label'   => esc_html__( 'Show Heading Meta', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);

		$this->add_control(
		    'show_heading',
		    [
		        'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
		        'type'    => Controls_Manager::SWITCHER,
		        'default' => 'yes',
		    ]
		);
		
		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		?>

		<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
		<div id="process" class="process section-padding text-center bg-img bg-fixed pos-re" data-overlay-dark="6" data-background="<?php echo wp_kses_post($settings['image']['url']); ?>" style="background-size: cover;">
		<?php endif; ?>

		<div class="container-fluid">

			<div class="row">

				<div class="col-md-12 item">

					<?php if (( '' !== $settings['heading_meta'] ) && ( $settings['show_heading_meta'] )): ?>
					<h2><?php echo wp_kses_post($settings['heading_meta']); ?></h2>
				<?php endif; ?>

				<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
				<h1><?php echo wp_kses_post($settings['heading']); ?></h1> 
			<?php endif; ?>

		</div>

	</div>

	<div class="row">

		<?php foreach ( $settings['tabs'] as $item ) : ?>
			<?php if( wp_kses_post($item['process_select']) == '1'): ?>

			<div class="col-md-3">

				<div class="item first mb-md50"> 
					
					<?php if ( '' !== $item['tab_image']['url'] ) : ?>
						<img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" class="tobotm" alt=""> 
					<?php endif; ?>
					

					<?php if ( '' !== $item['tab_icon'] ) : ?>
						<span class="icon <?php echo wp_kses_post($item['tab_icon']); ?>"></span>
					<?php endif; ?>

					<div class="cont">

						<?php if ( '' !== $item['tab_number'] ) : ?>
							<h3><?php echo wp_kses_post($item['tab_number']); ?></h3>
						<?php endif; ?>

						<?php if ( '' !== $item['tab_title'] ) : ?>
							<h6><?php echo wp_kses_post($item['tab_title']); ?></h6>
						<?php endif; ?>

						<?php if ( '' !== $item['tab_subtitle'] ) : ?>
							<p><?php echo wp_kses_post($item['tab_subtitle']); ?></p>
						<?php endif; ?>

					</div>

				</div>

			</div>

			<?php elseif( wp_kses_post($item['process_select']) == '2'): ?>

			<div class="col-md-3">

				<div class="item odd mb-md50"> 
					
					<?php if ( '' !== $item['tab_image']['url'] ) : ?>
						<img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt=""> 
					<?php endif; ?>
					

					<?php if ( '' !== $item['tab_icon'] ) : ?>
						<span class="icon <?php echo wp_kses_post($item['tab_icon']); ?>"></span>
					<?php endif; ?>

					<div class="cont">

						<?php if ( '' !== $item['tab_number'] ) : ?>
							<h3><?php echo wp_kses_post($item['tab_number']); ?></h3>
						<?php endif; ?>

						<?php if ( '' !== $item['tab_title'] ) : ?>
							<h6><?php echo wp_kses_post($item['tab_title']); ?></h6>
						<?php endif; ?>

						<?php if ( '' !== $item['tab_subtitle'] ) : ?>
							<p><?php echo wp_kses_post($item['tab_subtitle']); ?></p>
						<?php endif; ?>

					</div>

				</div>

			</div>

			<?php endif; ?>

		<?php endforeach; ?>

	</div>

	<div class="curve curve-gray-t curve-top"></div>

	<div class="curve curve-bottom"></div>

</div>

</div>
<?php if (is_admin()) { ?>
<script type="text/javascript">
    var pageSection = jQuery(".bg-img, section");
    pageSection.each(function(indx){
        if (jQuery(this).attr("data-background")){
            jQuery(this).css("background-image", "url(" + jQuery(this).data("background") + ")");
        }
    });
</script>
<?php }  ?>
		
	<?php
	}

}
