<?php

namespace BdevsElementor\Widget;



use Elementor\Controls_Manager;

use Elementor\Group_Control_Typography;

use Elementor\Scheme_Typography;

use Elementor\Group_Control_Border;

use Elementor\Group_Control_Box_Shadow;



/**

 * Bdevs Elementor Widget.

 *

 * Elementor widget that inserts an embbedable content into the page, from any given URL.

 *

 * @since 1.0.0

 */

class HomePersonalTeam extends \Elementor\Widget_Base {



	/**

	 * Get widget name.

	 *

	 * Retrieve Bdevs Elementor widget name.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget name.

	 */

	public function get_name() {

		return 'home-personal-team';

	}



	/**

	 * Get widget title.

	 *

	 * Retrieve Bdevs Elementor widget title.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget title.

	 */

	public function get_title() {

		return __( 'Home Personal - Team Widget', 'bdevs-elementor' );

	}



	/**

	 * Get widget icon.

	 *

	 * Retrieve Bdevs Slider widget icon.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return string Widget icon.

	 */

	public function get_icon() {

		return 'eicon-favorite';

	}



	/**

	 * Get widget categories.

	 *

	 * Retrieve the list of categories the Bdevs Slider widget belongs to.

	 *

	 * @since 1.0.0

	 * @access public

	 *

	 * @return array Widget categories.

	 */

	public function get_categories() {

		return [ 'home-personal' ];

	}



	public function get_keywords() {

		return [ 'Team', 'carousel' ];

	}



	public function get_script_depends() {

		return [ 'bdevs-elementor'];

	}



	// BDT Position

	protected function element_pack_position() {

	    $position_options = [

	        ''              => esc_html__('Default', 'bdevs-elementor'),

	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,

	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,

	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,

	        'center'        => esc_html__('Center', 'bdevs-elementor') ,

	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,

	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,

	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,

	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,

	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,

	    ];



	    return $position_options;

	}



	protected function _register_controls() {

		$this->start_controls_section(

			'section_team',

			[

				'label' => esc_html__( 'Team Area', 'bdevs-elementor' ),

			]

		);



		$this->add_control(

			'bg_select',

			[

				'label'     => esc_html__( 'Background Select', 'bdevs-elementor' ),

				'type'      => Controls_Manager::SELECT,

				'dynamic' => [ 'active' => true ],

				'options'   => [

					'1'  => esc_html__( 'Gray Background', 'bdevs-elementor' ),

					'2'  => esc_html__( 'No Color', 'bdevs-elementor' ),

				],

				'default'   => '1',

			]

		);





		$this->add_control(

			'heading_meta',

			[

				'label'       => __( 'Heading Meta', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your Heading Meta', 'bdevs-elementor' ),

				'default'     => __( 'It is Heading Meta', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'heading',

			[

				'label'       => __( 'Heading', 'bdevs-elementor' ),

				'type'        => Controls_Manager::TEXTAREA,

				'placeholder' => __( 'Enter your Heading', 'bdevs-elementor' ),

				'default'     => __( 'It is Heading', 'bdevs-elementor' ),

				'label_block' => true,

			]

		);



		$this->add_control(

			'tabs',

			[

				'label' => esc_html__( 'Tab Team', 'bdevs-elementor' ),

				'type' => Controls_Manager::REPEATER,

				'fields' => [	

					[

						'name'    => 'tab_image',

						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),

						'type'    => Controls_Manager::MEDIA,

						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),

					],	

					[

						'name'        => 'tab_name',

						'label'       => esc_html__( 'Tab Name', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'tab_position',

						'label'       => esc_html__( 'Tab Position', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'tab_social',

						'label'       => esc_html__( 'Tab Social', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '' , 'bdevs-elementor' ),

						'label_block' => true,

					],

					[

						'name'        => 'tab_email',

						'label'       => esc_html__( 'Tab Email', 'bdevs-elementor' ),

						'type'        => Controls_Manager::TEXTAREA,

						'dynamic'     => [ 'active' => true ],

						'default'     => esc_html__( '' , 'bdevs-elementor' ),

						'label_block' => true,

					],

				],

			]

		);



		$this->end_controls_section();





		

		$this->start_controls_section(

			'section_content_layout',

			[

				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),

			]

		);



		$this->add_responsive_control(

			'align',

			[

				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),

				'type'    => Controls_Manager::CHOOSE,

				'options' => [

					'left' => [

						'title' => esc_html__( 'Left', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-left',

					],

					'center' => [

						'title' => esc_html__( 'Center', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-center',

					],

					'right' => [

						'title' => esc_html__( 'Right', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-right',

					],

					'justify' => [

						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),

						'icon'  => 'fa fa-align-justify',

					],

				],

				'prefix_class' => 'elementor%s-align-',

				'description'  => 'Use align to match position',

				'default'      => 'center',

			]

		); 



		$this->add_control(

		    'show_heading_meta',

		    [

		        'label'   => esc_html__( 'Show Heading Meta', 'bdevs-elementor' ),

		        'type'    => Controls_Manager::SWITCHER,

		        'default' => 'yes',

		    ]

		);



		$this->add_control(

		    'show_heading',

		    [

		        'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),

		        'type'    => Controls_Manager::SWITCHER,

		        'default' => 'yes',

		    ]

		);

		

		$this->end_controls_section();



	}



	public function render() {



		$settings  = $this->get_settings_for_display();

		?>



		<?php if( wp_kses_post($settings['bg_select']) == '1'): ?>

		<div id="team" class="adco-section-padding bg-f7 adco-team adco-section-padding-2">

			<div class="container-fluid">

				<div class="row">

					<div class="col-md-12"> 

						<?php if (( '' !== $settings['heading_meta'] ) && ( $settings['show_heading_meta'] )): ?>

						<span class="heading-meta style-1"><?php echo wp_kses_post($settings['heading_meta']); ?></span>

					<?php endif; ?>



					<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>

					<h2 class="adco-heading animate-box" data-animate-effect="fadeInUp"><?php echo wp_kses_post($settings['heading']); ?></h2>

				<?php endif; ?>



			</div>



		</div>



		<div class="row">


			<?php elseif( wp_kses_post($settings['bg_select']) == '2'): ?>

		<div id="team" class="adco-section-padding adco-team">

			<div class="container-fluid">

				<div class="row">

					<div class="col-md-12"> 

						<?php if (( '' !== $settings['heading_meta'] ) && ( $settings['show_heading_meta'] )): ?>

						<span class="heading-meta style-1"><?php echo wp_kses_post($settings['heading_meta']); ?></span>

					<?php endif; ?>



					<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>

					<h2 class="adco-heading animate-box" data-animate-effect="fadeInUp"><?php echo wp_kses_post($settings['heading']); ?></h2>

				<?php endif; ?>



			</div>



		</div>



		<div class="row pb-60">

			<?php endif; ?> 



			<?php foreach ( $settings['tabs'] as $item ) : ?>



				<div class="col-md-4">



					<div class="team-holder pb-30 animate-box" data-animate-effect="fadeInUp">



						<div class="team-image-holder"> 



							<?php if ( '' !== $item['tab_image']['url'] ) : ?>

								<img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" class="img-fluid" alt="">

							<?php endif; ?>



							<div class="team-side-info">



								<?php if ( '' !== $item['tab_name'] ) : ?>

									<h4 class="team-name"><?php echo wp_kses_post($item['tab_name']); ?></h4>

								<?php endif; ?>



								<?php if ( '' !== $item['tab_position'] ) : ?>

									<h6 class="team-position"><?php echo wp_kses_post($item['tab_position']); ?></h6>

								<?php endif; ?>



							</div>



						</div>



						<?php if ( '' !== $item['tab_social'] ) : ?>

							<ul class="team-info-social">

								<?php echo wp_kses_post($item['tab_social']); ?>

							</ul>

						<?php endif; ?>



						<?php if ( '' !== $item['tab_email'] ) : ?>

							<p><?php echo wp_kses_post($item['tab_email']); ?></p>

						<?php endif; ?>



					</div>



				</div>



			<?php endforeach; ?>



		</div>



	</div>



</div>





		

	<?php

	}



}

